[maemo-commits] [maemo-commits] r13085 - in projects/haf/trunk/hildon-desktop: . libhildonwm src

From: subversion at stage.maemo.org subversion at stage.maemo.org
Date: Thu Aug 9 16:20:40 EEST 2007
Author: lucasr
Date: 2007-08-09 16:20:35 +0300 (Thu, 09 Aug 2007)
New Revision: 13085

Modified:
   projects/haf/trunk/hildon-desktop/ChangeLog
   projects/haf/trunk/hildon-desktop/libhildonwm/hd-wm.c
   projects/haf/trunk/hildon-desktop/src/hn-app-switcher.c
Log:
2007-08-09  Lucas Rocha  <lucas.rocha at nokia.com>

	* libhildonwm/hd-wm.c (hd_wm_process_x_client_list): notify stack
	changes when an application comes is activated from hibernation.
	Fixes NB#51276.


Modified: projects/haf/trunk/hildon-desktop/ChangeLog
===================================================================
--- projects/haf/trunk/hildon-desktop/ChangeLog	2007-08-09 13:14:15 UTC (rev 13084)
+++ projects/haf/trunk/hildon-desktop/ChangeLog	2007-08-09 13:20:35 UTC (rev 13085)
@@ -1,3 +1,9 @@
+2007-08-09  Lucas Rocha  <lucas.rocha at nokia.com>
+
+	* libhildonwm/hd-wm.c (hd_wm_process_x_client_list): notify stack
+	changes when an application comes is activated from hibernation.
+	Fixes NB#51276.
+
 2007-08-09  Johan Bilien  <johan.bilien at nokia.com>
 
 	* libhildondesktop/hildon-home-area.[ch],

Modified: projects/haf/trunk/hildon-desktop/libhildonwm/hd-wm.c
===================================================================
--- projects/haf/trunk/hildon-desktop/src/hn-app-switcher.c	2007-08-09 13:14:15 UTC (rev 13084)
+++ projects/haf/trunk/hildon-desktop/src/hn-app-switcher.c	2007-08-09 13:20:35 UTC (rev 13085)
@@ -1044,7 +1044,6 @@
   gboolean               active_found = FALSE;
 
   hd_wm_debug ("In hn_app_switcher_real_changed_stack");
-
   
   if (!entry_info || !hd_wm_entry_info_is_active (entry_info))
   {


More information about the maemo-commits mailing list
--- projects/haf/trunk/hildon-desktop/libhildonwm/hd-wm.c	2007-08-09 13:14:15 UTC (rev 13084)
+++ projects/haf/trunk/hildon-desktop/libhildonwm/hd-wm.c	2007-08-09 13:20:35 UTC (rev 13085)
@@ -1203,7 +1203,6 @@
     XSync (GDK_DISPLAY(),FALSE);
     
     gdk_error_trap_pop();
-
   }
 
   if (HD_WM_IS_DESKTOP (info))
@@ -1630,7 +1629,6 @@
   HDWMWindow *win;
   Window            *app_xwin;
 
-  
   if(hdwm->priv->active_window)
     previous_app_xwin = hd_wm_window_get_x_win (hdwm->priv->active_window);
   
@@ -1919,7 +1917,7 @@
 {
   struct xwinv xwins;
   int     i;
- 
+  
   /* Try to get desktop home window the first this function is called 
    * This is f*ck*ng expensive but it is supposed to work at the startup and 
    * you should forget about it 
@@ -2043,7 +2041,8 @@
     
       /* if the window does not have attached info yet, then it is new
        * and needs to be added to AS; if it has one, then it is coming
        * out of hibernation, in which case it must not be added
        */
       info = HD_WM_ENTRY_INFO (win);
 	   
@@ -2051,8 +2050,12 @@
       {
         hd_wm_debug ("Adding AS entry for view-less window\n");
         hd_wm_add_applications (hdwm,info);
-        g_signal_emit_by_name (hdwm,"entry_info_added",info);		
-       }
+        g_signal_emit_by_name (hdwm,"entry_info_added",info);
+      }
+      else
+      {
+        g_signal_emit_by_name (hdwm,"entry_info_stack_changed",info);
+      }
     }
   }
 
@@ -2043,7 +2041,8 @@
       /* if the window does not have attached info yet, then it is new
        * and needs to be added to AS; if it has one, then it is coming
-       * out of hibernation, in which case it must not be added
+       * out of hibernation, in which case it must not be added but the
+       * stack change is notified
        */
       info = HD_WM_ENTRY_INFO (win);

Modified: projects/haf/trunk/hildon-desktop/src/hn-app-switcher.c
===================================================================